@@ -71,13 +71,21 @@ def cleanup_value(value: any) -> any:
 def datetime_to_string(val: datetime.datetime) -> str:
     """Convert a datetime object to string.
 
+    If the supplied datetime does not specify a timezone,
+    it is assumed to be UTC.
+
     Args:
         val: The datetime object.
 
     Returns:
         datetime serialized to iso8601 format.
     """
-    return val.isoformat().replace('+00:00', 'Z')
+    if isinstance(val, datetime.datetime):
+        if val.tzinfo is None:
+            return val.isoformat() + 'Z'
+        val = val.astimezone(datetime.timezone.utc)
+        return val.isoformat().replace('+00:00', 'Z')
+    return val
 
 def string_to_datetime(string: str) -> datetime.datetime:
     """De-serializes string to datetime.
@@ -88,7 +96,10 @@ def string_to_datetime(string: str) -> datetime.datetime:
     Returns:
         the de-serialized string as a datetime object.
     """
-    return date_parser.parse(string)
+    val = date_parser.parse(string)
+    if val.tzinfo is not None:
+        return val
+    return val.replace(tzinfo=datetime.timezone.utc)
 
 def date_to_string(val: datetime.date) -> str:
     """Convert a date object to string.
@@ -99,7 +110,9 @@ def date_to_string(val: datetime.date) -> str:
     Returns:
         date serialized to `YYYY-MM-DD` format.
     """
-    return str(val)
+    if isinstance(val, datetime.date):
+        return str(val)
+    return val
 
 def string_to_date(string: str) -> datetime.date:
     """De-serializes string to date.
